@@ -2,17 +2,17 @@ import asyncio
 import msgpack
 from collections.abc import Iterator
 
-from typing import Any, List, Tuple, Type, Set, Union, _GenericAlias
+from typing import Any, List, Tuple, Optional, Type, Set, Union, _GenericAlias
 
 
 BASE_REQUEST_TYPE = Tuple[int, int, dict, Any]
-BASE_RESPONSE_TYPE = Tuple[int, int, dict, Any]
+BASE_RESPONSE_TYPE = Optional[Tuple[int, int, dict, Any]]
 LOOP_TYPE = asyncio.get_event_loop
 READER_TYPE = asyncio.streams.StreamReader
 WRITER_TYPE = asyncio.streams.StreamWriter
 UNPACKER_TYPE = msgpack.Unpacker
 
-_CAN_JSON_TYPE_SET: Set[type] = {bool, dict, float, int, list, str, tuple, type(None)}
+_CAN_JSON_TYPE_SET: Set[type] = {bool, dict, float, int, list, str, tuple, type(None), None}
 
 
 def parse_typing(_type: Type) -> Union[List[Type], Type]:
