@@ -4,123 +4,104 @@ import logging
 import time
 
 from dataclasses import dataclass
-from typing import Any, Callable, Coroutine, Dict, Optional, Tuple
+from typing import Any, Callable, Coroutine, Dict, Generator, Optional, Tuple
 
 from rap.common.conn import ServerConnection
 from rap.common.exceptions import (
-    AuthError,
     BaseRapError,
     FuncNotFoundError,
-    LifeCycleError,
     ParseError,
     ProtocolError,
-    ServerError,
     RpcRunTimeError,
+    ServerError
 )
 from rap.common.utlis import (
     Constant,
     Event,
-    MISS_OBJECT,
     get_event_loop,
     parse_error,
+    response_num_dict
 )
-from rap.manager.client_manager import client_manager, ClientModel, LifeCycleEnum
 from rap.manager.func_manager import func_manager
 from rap.server.response import Response, ResponseModel
 
 
 @dataclass()
 class RequestModel(object):
-    request_num: int
+    num: int
     msg_id: int
     header: dict
     body: Any
-    conn: ServerConnection
-    client_model: Optional[ClientModel] = None
 
 
 class Request(object):
-    def __init__(self, run_timeout: int):
+    def __init__(self, conn: ServerConnection, run_timeout: int):
+        self._conn: ServerConnection = conn
         self._run_timeout: int = run_timeout
-        self._request_num_dict: Dict[int, dict] = {
-            Constant.DECLARE_REQUEST: {
-                "func": self.declare_life_cycle,
-                "life_cycle": LifeCycleEnum.msg,
-                "response_num": Constant.DECLARE_RESPONSE,
-            },
-            Constant.MSG_REQUEST: {
-                "func": self.msg_life_cycle,
-                "life_cycle": LifeCycleEnum.msg,
-                "response_num": Constant.MSG_RESPONSE,
-            },
-            Constant.DROP_REQUEST: {
-                "func": self.drop_life_cycle,
-                "life_cycle": LifeCycleEnum.drop,
-                "response_num": Constant.DROP_REQUEST,
-            },
-            Constant.CLIENT_EVENT_RESPONSE: {
-                "func": self.event,
-                "life_cycle": LifeCycleEnum.msg,
-                "response_num": -1,
-            },
+        self.dispatch_func_dict: Dict[int, Callable] = {
+            Constant.DECLARE_REQUEST: self.declare_life_cycle,
         }
 
+        # now one conn one Request object
+        self._is_declare: bool = False
+        self._ping_pong_future: Optional[asyncio.Future] = None
+        self._keepalive_timestamp: int = int(time.time())
+        self._generator_dict: Dict[int, Generator] = {}
+
     async def dispatch(self, request: RequestModel) -> Optional[ResponseModel]:
-        dispatch_dict: dict = self._request_num_dict.get(request.request_num, None)
-        response_num: int = dispatch_dict.get("response_num", Constant.SERVER_ERROR_RESPONSE)
-
-        # create response_model
-        response: "ResponseModel" = ResponseModel(response_num=response_num, msg_id=request.msg_id)
-
-        # check type_id
-        if response_num is Constant.SERVER_ERROR_RESPONSE:
-            logging.error(f"parse request data: {request} from {request.header['_host']} error")
-            response.body = ServerError("response num error")
-            return response
-
-        # check client_model
-        if response_num == Constant.DECLARE_RESPONSE:
-            client_model: "ClientModel" = ClientModel()
+        if request.num not in self.dispatch_func_dict:
+            response_num: int = Constant.SERVER_ERROR_RESPONSE
+            content: str = 'life cycle error'
         else:
-            client_id = request.header.get("client_id", None)
-            client_model = client_manager.get_client_model(client_id)
-            if client_model is MISS_OBJECT:
-                response.body = AuthError("The current client id has not been registered")
-                return response
+            response_num: int = response_num_dict.get(request.num, Constant.SERVER_ERROR_RESPONSE)
+            content: str = 'request num error'
 
-        # check life_cycle
-        if not client_model.modify_life_cycle(dispatch_dict["life_cycle"]):
-            response.body = LifeCycleError()
+        response: "ResponseModel" = ResponseModel(num=response_num, msg_id=request.msg_id)
+        # check type_id
+        if response.num is Constant.SERVER_ERROR_RESPONSE:
+            logging.error(f"parse request data: {request} from {request.header['_host']} error")
+            response.body = ServerError(content)
+            return response
+        # check conn_data_model
+        if request.num != Constant.DECLARE_REQUEST and not self._is_declare:
+            response.body = ProtocolError('Must declare')
             return response
 
-        client_model.keep_alive_timestamp = int(time.time())
-        request.client_model = client_model
-        return await dispatch_dict["func"](request, response)
+        return await self.real_dispatch(request, response)
 
-    @staticmethod
-    async def ping_event(conn: ServerConnection, client_model: ClientModel):
-        response: Response = Response()
-        while not conn.is_closed():
-            diff_time: int = int(time.time()) - client_model.keep_alive_timestamp
+    async def real_dispatch(self, request: RequestModel, response: ResponseModel) -> ResponseModel:
+        dispatch_func: Callable = self.dispatch_func_dict[request.num]
+        return await dispatch_func(request, response)
+
+    async def ping_event(self):
+        response: Response = Response(self._conn)
+        while not self._conn.is_closed():
+            diff_time: int = int(time.time()) - self._keepalive_timestamp
             if diff_time > 130:
                 event_resp: ResponseModel = ResponseModel(
                     Constant.SERVER_EVENT, body=Event(Constant.EVENT_CLOSE_CONN, "recv pong timeout")
                 )
-                await response(conn, event_resp)
-                if not conn.is_closed():
-                    conn.close()
-                asyncio.ensure_future(client_manager.async_destroy_client_model(client_model.client_id))
+                await response(event_resp)
+                if not self._conn.is_closed():
+                    self._conn.close()
+                break
             else:
                 ping_response: ResponseModel = ResponseModel(Constant.SERVER_EVENT, body=Event(Constant.PING_EVENT, ""))
-                await response(conn, ping_response)
+                await response(ping_response)
                 await asyncio.sleep(60)
 
     async def declare_life_cycle(self, request: RequestModel, response: ResponseModel) -> ResponseModel:
-        client_manager.create_client_model(request.client_model)
-        response.body = {"client_id": request.client_model.client_id}
-        request.client_model.ping_event_future = asyncio.ensure_future(
-            self.ping_event(request.conn, request.client_model)
-        )
+        declare_id: str = request.body.get('declare_id', '')
+        if not declare_id:
+            response.body = ProtocolError('not found declare id')
+        self.dispatch_func_dict = {
+            Constant.MSG_REQUEST: self.msg_life_cycle,
+            Constant.DROP_REQUEST: self.drop_life_cycle,
+            Constant.CLIENT_EVENT_RESPONSE: self.event,
+        }
+        self._is_declare = True
+        self._ping_pong_future = asyncio.ensure_future(self.ping_event())
+        response.body = {'declare_id': declare_id[::-1]}
         return response
 
     async def msg_life_cycle(self, request: RequestModel, response: ResponseModel) -> ResponseModel:
@@ -144,43 +125,48 @@ class Request(object):
 
             new_call_id, result = await self.msg_handle(request, call_id, func, param)
             response.body = {"call_id": new_call_id, "method_name": method_name}
-            if isinstance(result, Exception):
+            if isinstance(result, StopAsyncIteration) or isinstance(result, StopIteration):
+                response.body["result"] = ""
+                response.header["status_code"] = 301
+            elif isinstance(result, Exception):
                 exc, exc_info = parse_error(result)
+                response.body['exc_info'] = exc_info
                 if request.header.get("user_agent") == Constant.USER_AGENT:
-                    response.body.update({"exc": exc, "exc_info": exc_info})
-                else:
-                    response.body.update({"exc_info": exc_info})
+                    response.body['exc'] = exc
             else:
                 response.body["result"] = result
         return response
 
-    @staticmethod
-    async def drop_life_cycle(request: RequestModel, response: ResponseModel) -> ResponseModel:
+    async def drop_life_cycle(self, request: RequestModel, response: ResponseModel) -> ResponseModel:
         call_id = request.body["call_id"]
-        client_manager.destroy_client_model(request.client_model.client_id)
+        if self._ping_pong_future:
+            if self._ping_pong_future.cancelled():
+                self._ping_pong_future.cancel()
+        self.dispatch_func_dict = {
+            Constant.DROP_REQUEST: self.drop_life_cycle,
+            Constant.CLIENT_EVENT_RESPONSE: self.event,
+        }
         response.body = {"call_id": call_id, "result": 1}
         return response
 
-    @staticmethod
-    async def event(request: RequestModel, response: ResponseModel) -> Optional[ResponseModel]:
+    async def event(self, request: RequestModel, response: ResponseModel) -> Optional[ResponseModel]:
         event_name: str = request.body[0]
         if event_name == Constant.PONG_EVENT:
-            client_id: str = request.header.get("client_id")
-            client_manager.get_client_model(client_id).keep_alive_timestamp = int(time.time())
+            self._keepalive_timestamp = int(time.time())
         return None
 
     async def msg_handle(self, request: RequestModel, call_id: int, func: Callable, param: str) -> Tuple[int, Any]:
         user_agent: str = request.header.get("user_agent")
         try:
-            if call_id in request.client_model.generator_dict:
+            if call_id in self._generator_dict:
                 try:
-                    result = request.client_model.generator_dict[call_id]
+                    result = self._generator_dict[call_id]
                     if inspect.isgenerator(result):
                         result = next(result)
                     elif inspect.isasyncgen(result):
                         result = await result.__anext__()
                 except (StopAsyncIteration, StopIteration) as e:
-                    del request.client_model.generator_dict[call_id]
+                    del self._generator_dict[call_id]
                     result = e
             else:
                 if asyncio.iscoroutinefunction(func):
@@ -200,14 +186,14 @@ class Request(object):
                         result = ProtocolError(f"{user_agent} not support generator")
                     else:
                         call_id = id(result)
-                        request.client_model.generator_dict[call_id] = result
+                        self._generator_dict[call_id] = result
                         result = next(result)
                 elif inspect.isasyncgen(result):
                     if user_agent != Constant.USER_AGENT:
                         result = ProtocolError(f"{user_agent} not support generator")
                     else:
                         call_id = id(result)
-                        request.client_model.generator_dict[call_id] = result
+                        self._generator_dict[call_id] = result
                         result = await result.__anext__()
         except Exception as e:
             if isinstance(e, BaseRapError):
